<p align="center"><h1 style="font-size: 50px" align="center">pydorm</h1></p>
<p align="center">
    <em>一个轻量级的python orm框架</em>
</p>
<p align="center">
<a href="https://pypi.org/project/pydorm" target="_blank">
    <img src="https://img.shields.io/pypi/v/pydorm?color=%2334D058&label=pypi%20package" alt="Package version">
</a>
<a href="https://pypi.org/project/py-seal" target="_blank">
    <img src="https://img.shields.io/pypi/pyversions/fastapi.svg?color=%2334D058" alt="Supported Python versions">
</a>
</p>
